@@ -320,7 +320,7 @@ class CsvParameterWidgets(object):
     def _do_layout(self):
         """Sizer hell, returns a sizer that contains all widgets"""
 
-        sizer_csvoptions = wx.FlexGridSizer(3, 4, 5, 5)
+        sizer_csvoptions = wx.FlexGridSizer(5, 4, 5, 5)
 
         # Adding parameter widgets to sizer_csvoptions
         leftpos = wx.LEFT | wx.ADJUST_MINSIZE
@@ -508,15 +508,17 @@ class CSVPreviewGrid(wx.grid.Grid):
             event.Skip()
             return 0
 
-        self.fill_cells(dialect, self.has_header)
+        self.fill_cells(dialect, self.has_header, choices=False)
 
-    def fill_cells(self, dialect, has_header):
+    def fill_cells(self, dialect, has_header, choices=True):
         """Fills the grid for preview of csv data
 
         Parameters
         ----------
         dialect: csv,dialect
         \tDialect used for csv reader
+        choices: Bool
+        \tCreate and show choices
 
         """
 
@@ -540,14 +542,15 @@ class CSVPreviewGrid(wx.grid.Grid):
             for i, header in enumerate(first_line):
                 self.SetCellValue(0, i, header)
 
-        # Add Choices
-        for col in xrange(self.shape[1]):
-            choice_renderer = ChoiceRenderer(self)
-            choice_editor = \
-                wx.grid.GridCellChoiceEditor(self.digest_types.keys(), False)
-            self.SetCellRenderer(has_header, col, choice_renderer)
-            self.SetCellEditor(has_header, col, choice_editor)
-            self.SetCellValue(has_header, col, digest_keys[col])
+        if choices:
+            # Add Choices
+            for col in xrange(self.shape[1]):
+                choice_renderer = ChoiceRenderer(self)
+                choice_editor = wx.grid.GridCellChoiceEditor(
+                    self.digest_types.keys(), False)
+                self.SetCellRenderer(has_header, col, choice_renderer)
+                self.SetCellEditor(has_header, col, choice_editor)
+                self.SetCellValue(has_header, col, digest_keys[col])
 
         # Fill in the rest of the lines
 
@@ -1277,9 +1280,16 @@ class PreferencesDialog(wx.Dialog):
             "widget_params": {"min": 0, "allow_long": True},
             "prepocessor": int,
         }),
-        ("gpg_key_uid", {
-            "label": _(u"GPG key name"),
-            "tooltip": _(u"Name of the GPG key for signing files"),
+        ("timer_interval", {
+            "label": _(u"Timer interval"),
+            "tooltip": _(u"Interval for periodic updating of timed cells."),
+            "widget": wx.lib.intctrl.IntCtrl,
+            "widget_params": {"min": 100, "allow_long": True},
+            "prepocessor": int,
+        }),
+        ("gpg_key_fingerprint", {
+            "label": _(u"GPG key id"),
+            "tooltip": _(u"Fingerprint of the GPG key for signing files"),
             "widget": wx.TextCtrl,
             "widget_params": {},
             "prepocessor": unicode,
