@@ -116,6 +116,7 @@ class GridCellEventMixin(object):
     FontUnderlineMsg, EVT_CMD_FONTUNDERLINE = new_command_event()
     FontStrikethroughMsg, EVT_CMD_FONTSTRIKETHROUGH = new_command_event()
     FrozenMsg, EVT_CMD_FROZEN = new_command_event()
+    LockMsg, EVT_CMD_LOCK = new_command_event()
     MergeMsg, EVT_CMD_MERGE = new_command_event()
     JustificationMsg, EVT_CMD_JUSTIFICATION = new_command_event()
     AlignmentMsg, EVT_CMD_ALIGNMENT = new_command_event()
@@ -165,6 +166,10 @@ class GridEventMixin(object):
     PasteMsg, EVT_CMD_PASTE = new_command_event()
     PasteAsMsg, EVT_CMD_PASTE_AS = new_command_event()
 
+    # Sorting events
+    SortAscendingMsg, EVT_CMD_SORT_ASCENDING = new_command_event()
+    SortDescendingMsg, EVT_CMD_SORT_DESCENDING = new_command_event()
+
     # Grid edit mode events
 
     SelectAll, EVT_CMD_SELECT_ALL = new_command_event()
@@ -176,6 +181,7 @@ class GridEventMixin(object):
 
     ViewFrozenMsg, EVT_CMD_VIEW_FROZEN = new_command_event()
     RefreshSelectionMsg, EVT_CMD_REFRESH_SELECTION = new_command_event()
+    TimerToggleMsg, EVT_CMD_TIMER_TOGGLE = new_command_event()
     DisplayGotoCellDialogMsg, EVT_CMD_DISPLAY_GOTO_CELL_DIALOG = \
         new_command_event()
     GotoCellMsg, EVT_CMD_GOTO_CELL = new_command_event()
@@ -237,6 +243,7 @@ class EntryLineEventMixin(object):
     """Mixin class for entry line events"""
 
     EntryLineMsg, EVT_ENTRYLINE_MSG = new_command_event()
+    LockEntryLineMsg, EVT_ENTRYLINE_LOCK = new_command_event()
     ##EntryLineSelectionMsg, EVT_ENTRYLINE_SELECTION_MSG = new_command_event()
 
 
