@@ -42,8 +42,9 @@ from _chart_dialog import ChartDialog
 
 import src.lib.i18n as i18n
 from src.sysvars import is_gtk
+from src.config import config
 
-import src.lib.xrect as xrect
+from src.lib.selection import Selection
 from src.model.model import CodeArray
 
 from src.actions._grid_actions import AllGridActions
@@ -129,6 +130,9 @@ class Grid(wx.grid.Grid, EventMixin):
         #  (When true, a cross-hatch is displayed for frozen cells)
         self._view_frozen = False
 
+        # Timer for updating frozen cells
+        self.timer_running = False
+
     def _layout(self):
         """Initial layout of grid"""
 
@@ -190,6 +194,7 @@ class Grid(wx.grid.Grid, EventMixin):
         main_window.Bind(self.EVT_CMD_FONTSTRIKETHROUGH,
                          c_handlers.OnCellFontStrikethrough)
         main_window.Bind(self.EVT_CMD_FROZEN, c_handlers.OnCellFrozen)
+        main_window.Bind(self.EVT_CMD_LOCK, c_handlers.OnCellLocked)
         main_window.Bind(self.EVT_CMD_MERGE, c_handlers.OnMerge)
         main_window.Bind(self.EVT_CMD_JUSTIFICATION,
                          c_handlers.OnCellJustification)
@@ -222,6 +227,9 @@ class Grid(wx.grid.Grid, EventMixin):
         main_window.Bind(self.EVT_CMD_VIEW_FROZEN, handlers.OnViewFrozen)
         main_window.Bind(self.EVT_CMD_REFRESH_SELECTION,
                          handlers.OnRefreshSelectedCells)
+        main_window.Bind(self.EVT_CMD_TIMER_TOGGLE,
+                         handlers.OnTimerToggle)
+        self.Bind(wx.EVT_TIMER, handlers.OnTimer)
         main_window.Bind(self.EVT_CMD_DISPLAY_GOTO_CELL_DIALOG,
                          handlers.OnDisplayGoToCellDialog)
         main_window.Bind(self.EVT_CMD_GOTO_CELL, handlers.OnGoToCell)
@@ -255,6 +263,10 @@ class Grid(wx.grid.Grid, EventMixin):
         main_window.Bind(wx.grid.EVT_GRID_ROW_SIZE, handlers.OnRowSize)
         main_window.Bind(wx.grid.EVT_GRID_COL_SIZE, handlers.OnColSize)
 
+        main_window.Bind(self.EVT_CMD_SORT_ASCENDING, handlers.OnSortAscending)
+        main_window.Bind(self.EVT_CMD_SORT_DESCENDING,
+                         handlers.OnSortDescending)
+
         # Undo/Redo events
 
         main_window.Bind(self.EVT_CMD_UNDO, handlers.OnUndo)
@@ -330,6 +342,18 @@ class Grid(wx.grid.Grid, EventMixin):
 
         post_command_event(self, self.EntryLineMsg, text=cell_code)
 
+    def lock_entry_line(self, lock):
+        """Lock or unlock entry line
+
+        Parameters
+        ----------
+        lock: Bool
+        \tIf True then the entry line is locked if Falsse unlocked
+
+        """
+
+        post_command_event(self, self.LockEntryLineMsg, lock=lock)
+
     def update_attribute_toolbar(self, key=None):
         """Updates the attribute toolbar
 
@@ -534,6 +558,17 @@ class GridCellEventHandlers(object):
 
         event.Skip()
 
+    def OnCellLocked(self, event):
+        """Cell locked event handler"""
+
+        self.grid.actions.toggle_attr("locked")
+
+        self.grid.ForceRefresh()
+
+        self.grid.update_attribute_toolbar()
+
+        event.Skip()
+
     def OnMerge(self, event):
         """Merge cells event handler"""
 
@@ -636,7 +671,10 @@ class GridCellEventHandlers(object):
         self.grid.update_attribute_toolbar()
 
         if is_gtk():
-            wx.Yield()
+            try:
+                wx.Yield()
+            except:
+                pass
 
         event.Skip()
 
@@ -669,6 +707,10 @@ class GridCellEventHandlers(object):
         # Redraw cursor
         self.grid.ForceRefresh()
 
+        # Disable entry line if cell is locked
+        self.grid.lock_entry_line(
+            self.grid.code_array.cell_attributes[key]["locked"])
+
         # Update entry line
         self.grid.update_entry_line(key)
 
@@ -713,49 +755,46 @@ class GridEventHandlers(object):
     def OnKey(self, event):
         """Handles non-standard shortcut events"""
 
+        grid = self.grid
+        actions = grid.actions
+
+        shift, alt, ctrl = 1, 1 << 1, 1 << 2
+
+        # Shortcuts key tuple: (modifier, keycode)
+        # Modifier may be e. g. shift | ctrl
+
+        shortcuts = {
+            # <Esc> pressed
+            (0, 27): lambda: setattr(actions, "need_abort", True),
+            # <Del> pressed
+            (0, 127): actions.delete,
+            # <Home> pressed
+            (0, 313): lambda: actions.set_cursor((grid.GetGridCursorRow(), 0)),
+            # <Ctrl> + R pressed
+            (ctrl, 82): actions.copy_selection_access_string,
+            # <Ctrl> + + pressed
+            (ctrl, 388): actions.zoom_in,
+            # <Ctrl> + - pressed
+            (ctrl, 390): actions.zoom_out,
+            # <Shift> + <Space> pressed
+            (shift, 32): lambda: grid.SelectRow(grid.GetGridCursorRow()),
+            # <Ctrl> + <Space> pressed
+            (ctrl, 32): lambda: grid.SelectCol(grid.GetGridCursorCol()),
+            # <Shift> + <Ctrl> + <Space> pressed
+            (shift | ctrl, 32): grid.SelectAll,
+        }
+
         keycode = event.GetKeyCode()
+        #print keycode
 
-        # If in selection mode and <Enter> is pressed end it
-        if not self.grid.IsEditable() and keycode == 13:
-            ## TODO!
-            pass
+        modifier = shift * event.ShiftDown() | \
+            alt * event.AltDown() | ctrl * event.ControlDown()
 
-        elif event.ControlDown():
-            if keycode == 388:
-                # Ctrl + + pressed
-                post_command_event(self.grid, self.grid.ZoomInMsg)
-
-            elif keycode == 390:
-                # Ctrl + - pressed
-                post_command_event(self.grid, self.grid.ZoomOutMsg)
+        if (modifier, keycode) in shortcuts:
+            shortcuts[(modifier, keycode)]()
 
         else:
-            # No Ctrl pressed
-
-            if keycode == 127:
-                # Del pressed
-
-                # Is grid selection present? --> Delete current cell
-                if self.grid.IsSelection():
-                    # Delete selection
-                    self.grid.actions.delete_selection()
-
-                else:
-                    # Delete cell at cursor
-                    cursor = self.grid.actions.cursor
-                    self.grid.actions.delete_cell(cursor)
-
-                # Update grid
-                self.grid.ForceRefresh()
-
-                # Do not enter cell
-                return
-
-            elif keycode == 27:
-                # Esc pressed
-                self.grid.actions.need_abort = True
-
-        event.Skip()
+            event.Skip()
 
     def OnRangeSelected(self, event):
         """Event handler for grid selection"""
@@ -794,7 +833,18 @@ class GridEventHandlers(object):
 
         row, col, tab = event.key
 
-        self.grid.actions.cursor = row, col, tab
+        try:
+            self.grid.actions.cursor = row, col, tab
+
+        except ValueError:
+            msg = _("Cell {key} outside grid shape {shape}").format(
+                key=event.key, shape=self.grid.code_array.shape)
+            post_command_event(self.grid.main_window, self.grid.StatusBarMsg,
+                               text=msg)
+
+            event.Skip()
+            return
+
         self.grid.MakeCellVisible(row, col)
 
         event.Skip()
@@ -821,6 +871,31 @@ class GridEventHandlers(object):
 
         event.Skip()
 
+    def OnTimerToggle(self, event):
+        """Toggles the timer for updating frozen cells"""
+
+        if self.grid.timer_running:
+            # Stop timer
+            self.grid.timer_running = False
+            self.grid.timer.Stop()
+            del self.grid.timer
+
+        else:
+            # Start timer
+            self.grid.timer_running = True
+            self.grid.timer = wx.Timer(self.grid)
+            self.grid.timer.Start(config["timer_interval"])
+
+    def OnTimer(self, event):
+        """Update all frozen cells because of timer call"""
+
+        self.timer_updating = True
+
+        shape = self.grid.code_array.shape[:2]
+        selection = Selection([(0, 0)], [(shape)], [], [], [])
+        self.grid.actions.refresh_selected_frozen_cells(selection)
+        self.grid.ForceRefresh()
+
     def OnZoomIn(self, event):
         """Event handler for increasing grid zoom"""
 
@@ -862,6 +937,9 @@ class GridEventHandlers(object):
             else:
                 post_command_event(self.grid, self.grid.ZoomOutMsg)
         else:
+            x, y = self.grid.GetViewStart()
+            direction = 1 if event.GetWheelRotation() < 0 else -1
+            self.grid.Scroll(x, y + direction)
             event.Skip()
 
     # Find events
@@ -1164,7 +1242,7 @@ class GridEventHandlers(object):
         # Detect for resizing group of rows
         rows = self.grid.GetSelectedRows()
         if len(rows) == 0:
-            rows = [row,]
+            rows = [row, ]
 
         # Detect for selection of rows spanning all columns
         selection = self.grid.selection
@@ -1184,7 +1262,6 @@ class GridEventHandlers(object):
         event.Skip()
         self.grid.Refresh()
 
-
     def OnColSize(self, event):
         """Column size event handler"""
 
@@ -1195,7 +1272,7 @@ class GridEventHandlers(object):
         # Detect for resizing group of cols
         cols = self.grid.GetSelectedCols()
         if len(cols) == 0:
-            cols = [col,]
+            cols = [col, ]
 
         # Detect for selection of rows spanning all columns
         selection = self.grid.selection
@@ -1215,6 +1292,32 @@ class GridEventHandlers(object):
         event.Skip()
         self.grid.Refresh()
 
+    def OnSortAscending(self, event):
+        """Sort ascending event handler"""
+
+        try:
+            self.grid.actions.sort_ascending(self.grid.actions.cursor)
+            statustext = _(u"Sorting complete.")
+
+        except Exception, err:
+            statustext = _(u"Sorting failed: {}").format(err)
+
+        post_command_event(self.grid.main_window, self.grid.StatusBarMsg,
+                           text=statustext)
+
+    def OnSortDescending(self, event):
+        """Sort descending event handler"""
+
+        try:
+            self.grid.actions.sort_descending(self.grid.actions.cursor)
+            statustext = _(u"Sorting complete.")
+
+        except Exception, err:
+            statustext = _(u"Sorting failed: {}").format(err)
+
+        post_command_event(self.grid.main_window, self.grid.StatusBarMsg,
+                           text=statustext)
+
     # Undo and redo events
 
     def OnUndo(self, event):
@@ -1241,4 +1344,4 @@ class GridEventHandlers(object):
         self.grid.update_entry_line()
         self.grid.update_attribute_toolbar()
 
-# End of class GridEventHandlers
\ No newline at end of file
+# End of class GridEventHandlers
