@@ -187,7 +187,7 @@ class MainMenu(_filledMenu, EventMixin):
                 [item, [self.SaveMsg, _("&Save") + "\tCtrl+s",
                         _("Save spreadsheet"), wx.ID_SAVE]],
                 [item, [self.SaveAsMsg, _("Save &As") + "\tShift+Ctrl+s",
-                        _("Save spreadsheet to a new file")], wx.ID_SAVEAS],
+                        _("Save spreadsheet to a new file")]],
                 ["Separator"],
                 [item, [self.ImportMsg, _("&Import"),
                         _("Import a file and paste it into current grid")]],
@@ -226,8 +226,9 @@ class MainMenu(_filledMenu, EventMixin):
                         _("Copy the input strings of the cells to clipboard"),
                         wx.ID_COPY]],
                 [item, [self.CopyResultMsg,
-                        _("Copy &Results") + "\tShift+Ctrl+c", _("Copy the "
-                        "result strings of the cells to the clipboard")]],
+                        _("Copy &Results") + "\tShift+Ctrl+c",
+                        _("Copy the result strings of the cells to the "
+                          "clipboard")]],
                 [item, [self.PasteMsg, _("&Paste") + "\tCtrl+v",
                         _("Paste cells from clipboard"), wx.ID_PASTE]],
                 [item, [self.PasteAsMsg, _("Paste &As...") + "\tShift+Ctrl+v",
@@ -245,6 +246,13 @@ class MainMenu(_filledMenu, EventMixin):
                           '("). If a selection is present then its cells are '
                           'quoted.')]],
                 ["Separator"],
+                [item, [self.SortAscendingMsg, _("Sort &ascending"),
+                        _("Sort rows in selection or current table ascending "
+                          "corresponding to row at cursor.")]],
+                [item, [self.SortDescendingMsg, _("Sort &descending"),
+                        _("Sort rows in selection or current table descending "
+                          "corresponding to row at cursor.")]],
+                ["Separator"],
                 [item, [self.InsertRowsMsg, _("Insert &rows"),
                         _("Insert rows at cursor")]],
                 [item, [self.InsertColsMsg, _("&Insert columns"),
@@ -294,11 +302,15 @@ class MainMenu(_filledMenu, EventMixin):
                         _("Refresh selected cells") + "\tF5",
                         _("Refresh selected cells even when frozen"),
                         wx.ID_REFRESH]],
+                [item, [self.TimerToggleMsg,
+                        _("Toggle periodic updates"),
+                        _("Toggles periodic cell updates for frozen cells")],
+                 wx.ITEM_CHECK],
                 ["Separator"],
                 [item, [self.ViewFrozenMsg, _("Show Frozen"),
                         _("Shows which cells are currently frozen in a "
-                        "crosshatch.")],
-                        wx.ITEM_CHECK]]],
+                          "crosshatch.")],
+                 wx.ITEM_CHECK]]],
             [wx.Menu, _("F&ormat"), [
                 [item, [self.FontDialogMsg, _("Font..."),
                         _("Launch font dialog.")]],
@@ -314,7 +326,9 @@ class MainMenu(_filledMenu, EventMixin):
                 [item, [self.FrozenMsg, _("Frozen"),
                         _("Toggles frozen state of cell. ") +
                         _("Frozen cells are updated only "
-                        "when F5 is pressed.")]],
+                          "when F5 is pressed.")]],
+                [item, [self.LockMsg, _("Lock"),
+                        _("Lock cell. Locked cells cannot be changed.")]],
                 [item, [self.MergeMsg, _("Merge cells"),
                         _("Merges / unmerges selected cells. ")]],
 
@@ -335,7 +349,7 @@ class MainMenu(_filledMenu, EventMixin):
                         _("Launch color dialog to specify text color.")]],
                 [item, [self.BgColorDialogMsg, _("Background color..."),
                         _("Launch color dialog to specify background "
-                        "color.")]],
+                          "color.")]],
                 ["Separator"],
                 [item, [self.RotationDialogMsg, _("Rotation..."),
                         _("Set text rotation.")]]]],
@@ -361,9 +375,6 @@ class MainMenu(_filledMenu, EventMixin):
                 [item, [self.FaqMsg, _("&FAQ"),
                         _("Frequently asked questions")]],
                 ["Separator"],
-                [item, [self.PythonTutorialMsg, _("&Python tutorial"),
-                        _("Python tutorial for coding information (online)")]],
-                ["Separator"],
                 [item, [self.AboutMsg, _("&About"), _("About pyspread"),
                         wx.ID_ABOUT]]]]
         ]
