@@ -49,21 +49,22 @@ from src.gui._gui_interfaces import get_key_params_from_user
 _ = i18n.language.ugettext
 
 
-def choose_uid_key(keylist):
-    """Displays gpg key choice and returns uid and key dict"""
+def choose_key(gpg_private_keys, gpg_private_fingerprints):
+    """Displays gpg key choice and returns key"""
 
-    uid_strings = []
-    uid_string2key = {}
+    uid_strings_fp = []
+    uid_string_fp2key = {}
 
-    for key in keylist:
+    for key, fingerprint in zip(gpg_private_keys, gpg_private_fingerprints):
         for uid_string in key['uids']:
-            uid_strings.append(uid_string)
-            uid_string2key[uid_string] = key
+            uid_string_fp = '"' + uid_string + ' (' + fingerprint + ')'
+            uid_strings_fp.append(uid_string_fp)
+            uid_string_fp2key[uid_string_fp] = key
 
     msg = _('Choose a GPG key for signing pyspread save files.\n'
             'The GPG key must not have a passphrase set.')
 
-    dlg = wx.SingleChoiceDialog(None, msg, _('Choose key'), uid_strings,
+    dlg = wx.SingleChoiceDialog(None, msg, _('Choose key'), uid_strings_fp,
                                 wx.CHOICEDLG_STYLE)
 
     dlg.SetBestFittingSize()
@@ -73,16 +74,15 @@ def choose_uid_key(keylist):
     childlist[-2].SetLabel(_("Create new key"))
 
     if dlg.ShowModal() == wx.ID_OK:
-        uid = dlg.GetStringSelection()
-        key = uid_string2key[uid]
+        uid_string_fp = dlg.GetStringSelection()
+        key = uid_string_fp2key[uid_string_fp]
 
     else:
-        uid = None
         key = None
 
     dlg.Destroy()
 
-    return uid, key
+    return key
 
 
 def genkey():
@@ -94,22 +94,26 @@ def genkey():
 
     # Check if standard key is already present
 
-    pyspread_key_uid = str(config["gpg_key_uid"])
-    gpg_private_keylist = gpg.list_keys(True)
+    pyspread_key_fingerprint = str(config["gpg_key_fingerprint"])
+    gpg_private_keys = gpg.list_keys(True)
+    gpg_private_fingerprints = gpg.list_keys(True).fingerprints
 
     pyspread_key = None
 
-    for private_key in gpg_private_keylist:
-        if pyspread_key_uid in private_key["uids"]:
+    for private_key, fingerprint in zip(gpg_private_keys,
+                                        gpg_private_fingerprints):
+        if pyspread_key_fingerprint == fingerprint:
             pyspread_key = private_key
 
     if pyspread_key is None:
         # If no GPG key is set in config, choose one
-        pyspread_key_uid, pyspread_key = choose_uid_key(gpg_private_keylist)
+        pyspread_key = choose_key(gpg_private_keys, gpg_private_fingerprints)
 
     if pyspread_key:
         # A key has been chosen
-        config["gpg_key_uid"] = repr(pyspread_key_uid)
+        fingerprint = \
+            gpg_private_fingerprints[gpg_private_keys.index(pyspread_key)]
+        config["gpg_key_fingerprint"] = repr(fingerprint)
 
     else:
         # No key has been chosen --> Create new one
@@ -138,7 +142,8 @@ def genkey():
 
             for private_key in gpg.list_keys(True):
                 if str(fingerprint) == private_key['fingerprint']:
-                    config["gpg_key_uid"] = repr(private_key['uids'][0])
+                    config["gpg_key_fingerprint"] = repr(
+                        private_key.fingerprint)
 
         else:
             dlg.Destroy()
@@ -152,7 +157,7 @@ def sign(filename):
 
     signfile = open(filename, "rb")
 
-    signed_data = gpg.sign_file(signfile, keyid=config["gpg_key_uid"],
+    signed_data = gpg.sign_file(signfile, keyid=config["gpg_key_fingerprint"],
                                 detach=True)
     signfile.close()
 
@@ -170,4 +175,4 @@ def verify(sigfilename, filefilename=None):
 
     sigfile.close()
 
-    return verified
\ No newline at end of file
+    return verified
